from collections.abc import Sequence

from pydantic_ai.agent import Agent, AgentRunResult
from pydantic_ai.messages import UserContent

from lightblue_ai.mcps import get_mcp_servers
from lightblue_ai.models import infer_model
from lightblue_ai.prompts import get_context, get_system_prompt
from lightblue_ai.settings import Settings
from lightblue_ai.tools.manager import LightBlueToolManager


class LightBlueAgent:
    def __init__(self):
        self.tool_manager = LightBlueToolManager()
        self.settings = Settings()

        self.agent = Agent(
            infer_model(self.settings.default_model),
            system_prompt=get_system_prompt(
                context=get_context(),
            ),
            tools=self.tool_manager.get_all_tools(),
            mcp_servers=get_mcp_servers(),
        )

    async def run(self, user_prompt: str | Sequence[UserContent]) -> AgentRunResult[str]:
        async with self.agent.run_mcp_servers():
            return await self.agent.run(user_prompt)



from pathlib import Path

from pydantic_settings import BaseSettings, SettingsConfigDict


class Settings(BaseSettings):
    default_model: str
    sub_agent_model: str | None = None

    tavily_api_key: str | None = None
    bfl_api_key: str | None = None
    urlbox_api_key: str | None = None

    mcp_config_path: str = (Path.cwd() / "./mcp.json").expanduser().resolve().absolute().as_posix()

    model_config = SettingsConfigDict(case_sensitive=False, frozen=True, env_file=".env")
